<?php

namespace Litecms\Importexport\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\Importexport\Forms\Import as ImportForm;
use Litecms\Importexport\Http\Requests\ImportRequest;
use Litecms\Importexport\Interfaces\ImportRepositoryInterface;
use Litecms\Importexport\Repositories\Eloquent\Filters\ImportResourceFilter;
use Litecms\Importexport\Repositories\Eloquent\Presenters\ImportListPresenter;

/**
 * Resource controller class for import.
 */
class ImportResourceController extends BaseController
{

    /**
     * Initialize import resource controller.
     *
     *
     * @return null
     */
    public function __construct(ImportRepositoryInterface $import)
    {
        parent::__construct();
        $this->form = ImportForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.importexport.modules'), 'importexport', guard_url('importexport'));
        $this->repository = $import;
    }

    /**
     * Display a list of import.
     *
     * @return Response
     */
    public function index(ImportRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ImportResourceFilter::class)
            ->setPresenter(ImportListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('importexport::import.names'))
            ->view('importexport::import.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display import.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function show(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('importexport::import.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('importexport::import.show')
            ->output();
    }

    /**
     * Show the form for creating a new import.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('importexport::import.name'))
            ->view('importexport::import.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new import.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('importexport::import.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('importexport/import/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/importexport/import'))
                ->redirect();
        }

    }

    /**
     * Show import for editing.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function edit(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('importexport::import.name'))
            ->view('importexport::import.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the import.
     *
     * @param Request $request
     * @param Model   $import
     *
     * @return Response
     */
    public function update(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('importexport::import.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('importexport/import/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('importexport/import/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the import.
     *
     * @param Model   $import
     *
     * @return Response
     */
    public function destroy(ImportRequest $request, ImportRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('importexport::import.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('importexport/import/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('importexport/import/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
